use nxui::demo::demowindow::DemoWindow;

fn main() {
    let win = DemoWindow::new();
    nxui::nxui::create_new_app(Box::new(win));
}